<?php

namespace HiccupApi\Model;

use JMS\Serializer\Annotation as Serializer;

/**
 * Class Error
 * @package HiccupApi\Model
 * @Serializer\ExclusionPolicy("all")
 */
final class ErrorResponse
{
    #----------------------------------------------------------------------------------------------
    # Properties
    #----------------------------------------------------------------------------------------------

    /**
     * Problem Type
     *
     * An absolute URI that identifies the problem type.
     * When dereferenced, it should provide human-readable documentation for the problem type.
     *
     * @var string
     *
     * @Serializer\Expose()
     * @Serializer\Type("string")
     */
    private $type;

    /**
     * Error Title
     *
     * A short, human-readable summary of the problem type.
     * It shouldn't change based on the occurrence of the problem, except for purposes of localization.
     *
     * @var string
     *
     * @Serializer\Expose()
     * @Serializer\Type("string")
     */
    private $title;

    /**
     * HTTP Status Code
     *
     * The HTTP status code (RFC2616, Section 6) generated by the origin server for this occurrence of the problem.
     *
     * @var string
     *
     * @Serializer\Expose()
     * @Serializer\Type("string")
     */
    private $status;

    /**
     * Error Message
     *
     * A human-readable explanation specific to this occurrence of the problem.
     *
     * @var string
     * @see https://developer.mailchimp.com/documentation/mailchimp/guides/get-started-with-mailchimp-api-3/#errors
     *
     * @Serializer\Expose()
     * @Serializer\Type("string")
     */
    private $detail;

    /**
     * Instance ID
     *
     * A string that identifies this specific occurrence of the problem. Please provide this ID when contacting support.
     *
     * @var string
     *
     * @Serializer\Expose()
     * @Serializer\Type("string")
     */
    private $instance;

    #----------------------------------------------------------------------------------------------
    # Properties accessor
    #----------------------------------------------------------------------------------------------

    /**
     * @return string
     */
    public function getType(): string
    {
        return $this->type;
    }

    /**
     * @param string $type
     */
    public function setType(string $type)
    {
        $this->type = $type;
    }

    /**
     * @return string
     */
    public function getTitle(): string
    {
        return $this->title;
    }

    /**
     * @param string $title
     */
    public function setTitle(string $title)
    {
        $this->title = $title;
    }

    /**
     * @return string
     */
    public function getStatus(): string
    {
        return $this->status;
    }

    /**
     * @param string $status
     */
    public function setStatus(string $status)
    {
        $this->status = $status;
    }

    /**
     * @return string
     */
    public function getDetail(): string
    {
        return $this->detail;
    }

    /**
     * @param string $detail
     */
    public function setDetail(string $detail)
    {
        $this->detail = $detail;
    }

    /**
     * @return string
     */
    public function getInstance(): string
    {
        return $this->instance;
    }

    /**
     * @param string $instance
     */
    public function setInstance(string $instance)
    {
        $this->instance = $instance;
    }
}
